#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   Issue #350 is still open: on Windows, the code here causes it to link
   with PYTHON36.DLL (for example) instead of PYTHON3.DLL.  A fix was
   attempted in 164e526a5515 and 14ce6985e1c3, but reverted: virtualenv
   does not make PYTHON3.DLL available, and so the "correctly" compiled
   version would not run inside a virtualenv.  We will re-apply the fix
   after virtualenv has been fixed for some time.  For explanation, see
   issue #355.  For a workaround if you want PYTHON3.DLL and don't worry
   about virtualenv, see issue #350.  See also 'py_limited_api' in
   setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  include <pyconfig.h>
#  if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG)
#    define Py_LIMITED_API
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t(x);
}


/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/


#include <smi.h>


/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // SmiElement *()(SmiElement *)
/*  1 */ _CFFI_OP(_CFFI_OP_POINTER, 96), // SmiElement *
/*  2 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  3 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // SmiElement *()(SmiNode *)
/*  4 */ _CFFI_OP(_CFFI_OP_POINTER, 100), // SmiNode *
/*  5 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  6 */ _CFFI_OP(_CFFI_OP_FUNCTION, 7), // SmiModule *()(SmiModule *)
/*  7 */ _CFFI_OP(_CFFI_OP_POINTER, 98), // SmiModule *
/*  8 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  9 */ _CFFI_OP(_CFFI_OP_FUNCTION, 7), // SmiModule *()(SmiNode *)
/* 10 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 11 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 12 */ _CFFI_OP(_CFFI_OP_FUNCTION, 7), // SmiModule *()(SmiType *)
/* 13 */ _CFFI_OP(_CFFI_OP_POINTER, 102), // SmiType *
/* 14 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 15 */ _CFFI_OP(_CFFI_OP_FUNCTION, 7), // SmiModule *()(char const *)
/* 16 */ _CFFI_OP(_CFFI_OP_POINTER, 104), // char const *
/* 17 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 18 */ _CFFI_OP(_CFFI_OP_FUNCTION, 7), // SmiModule *()(void)
/* 19 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 20 */ _CFFI_OP(_CFFI_OP_FUNCTION, 21), // SmiNamedNumber *()(SmiNamedNumber *)
/* 21 */ _CFFI_OP(_CFFI_OP_POINTER, 99), // SmiNamedNumber *
/* 22 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 23 */ _CFFI_OP(_CFFI_OP_FUNCTION, 21), // SmiNamedNumber *()(SmiType *)
/* 24 */ _CFFI_OP(_CFFI_OP_NOOP, 13),
/* 25 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 26 */ _CFFI_OP(_CFFI_OP_FUNCTION, 4), // SmiNode *()(SmiElement *)
/* 27 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 28 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 29 */ _CFFI_OP(_CFFI_OP_FUNCTION, 4), // SmiNode *()(SmiModule *, char const *)
/* 30 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 31 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 32 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 33 */ _CFFI_OP(_CFFI_OP_FUNCTION, 4), // SmiNode *()(SmiModule *, unsigned int)
/* 34 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 35 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8), // unsigned int
/* 36 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 37 */ _CFFI_OP(_CFFI_OP_FUNCTION, 4), // SmiNode *()(SmiNode *)
/* 38 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 39 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 40 */ _CFFI_OP(_CFFI_OP_FUNCTION, 4), // SmiNode *()(SmiNode *, unsigned int)
/* 41 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 42 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 43 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 44 */ _CFFI_OP(_CFFI_OP_FUNCTION, 4), // SmiNode *()(unsigned int, unsigned int *)
/* 45 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 46 */ _CFFI_OP(_CFFI_OP_POINTER, 35), // unsigned int *
/* 47 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 48 */ _CFFI_OP(_CFFI_OP_FUNCTION, 49), // SmiRange *()(SmiRange *)
/* 49 */ _CFFI_OP(_CFFI_OP_POINTER, 101), // SmiRange *
/* 50 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 51 */ _CFFI_OP(_CFFI_OP_FUNCTION, 49), // SmiRange *()(SmiType *)
/* 52 */ _CFFI_OP(_CFFI_OP_NOOP, 13),
/* 53 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 54 */ _CFFI_OP(_CFFI_OP_FUNCTION, 13), // SmiType *()(SmiModule *, char *)
/* 55 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 56 */ _CFFI_OP(_CFFI_OP_POINTER, 104), // char *
/* 57 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 58 */ _CFFI_OP(_CFFI_OP_FUNCTION, 13), // SmiType *()(SmiNode *)
/* 59 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 60 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 61 */ _CFFI_OP(_CFFI_OP_FUNCTION, 13), // SmiType *()(SmiType *)
/* 62 */ _CFFI_OP(_CFFI_OP_NOOP, 13),
/* 63 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 64 */ _CFFI_OP(_CFFI_OP_FUNCTION, 56), // char *()(SmiNode *, int)
/* 65 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 66 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7), // int
/* 67 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 68 */ _CFFI_OP(_CFFI_OP_FUNCTION, 56), // char *()(char const *)
/* 69 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 70 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 71 */ _CFFI_OP(_CFFI_OP_FUNCTION, 56), // char *()(void)
/* 72 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 73 */ _CFFI_OP(_CFFI_OP_FUNCTION, 66), // int()(char const *)
/* 74 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 75 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 76 */ _CFFI_OP(_CFFI_OP_FUNCTION, 113), // void()(char *, int, int, char *, char *)
/* 77 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 78 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 79 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 80 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 81 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 82 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 83 */ _CFFI_OP(_CFFI_OP_FUNCTION, 113), // void()(int)
/* 84 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 85 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 86 */ _CFFI_OP(_CFFI_OP_FUNCTION, 113), // void()(void *)
/* 87 */ _CFFI_OP(_CFFI_OP_POINTER, 113), // void *
/* 88 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 89 */ _CFFI_OP(_CFFI_OP_FUNCTION, 113), // void()(void(*)(char *, int, int, char *, char *))
/* 90 */ _CFFI_OP(_CFFI_OP_POINTER, 76), // void(*)(char *, int, int, char *, char *)
/* 91 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 92 */ _CFFI_OP(_CFFI_OP_FUNCTION, 113), // void()(void)
/* 93 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 94 */ _CFFI_OP(_CFFI_OP_ENUM, 0), // SmiAccess
/* 95 */ _CFFI_OP(_CFFI_OP_ENUM, 1), // SmiBasetype
/* 96 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 1), // SmiElement
/* 97 */ _CFFI_OP(_CFFI_OP_ENUM, 2), // SmiIndexkind
/* 98 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 2), // SmiModule
/* 99 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 3), // SmiNamedNumber
/* 100 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 4), // SmiNode
/* 101 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 5), // SmiRange
/* 102 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 6), // SmiType
/* 103 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 7), // SmiValue
/* 104 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 2), // char
/* 105 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14), // double
/* 106 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 13), // float
/* 107 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 15), // long double
/* 108 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 11), // long long
/* 109 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9), // long
/* 110 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 0), // union $1
/* 111 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 12), // unsigned long long
/* 112 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10), // unsigned long
/* 113 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

static int _cffi_const_SMI_ACCESS_NOT_IMPLEMENTED(unsigned long long *o)
{
  int n = (SMI_ACCESS_NOT_IMPLEMENTED) <= 0;
  *o = (unsigned long long)((SMI_ACCESS_NOT_IMPLEMENTED) | 0);  /* check that SMI_ACCESS_NOT_IMPLEMENTED is an integer */
  return n;
}

static int _cffi_const_SMI_ACCESS_NOT_ACCESSIBLE(unsigned long long *o)
{
  int n = (SMI_ACCESS_NOT_ACCESSIBLE) <= 0;
  *o = (unsigned long long)((SMI_ACCESS_NOT_ACCESSIBLE) | 0);  /* check that SMI_ACCESS_NOT_ACCESSIBLE is an integer */
  return n;
}

static int _cffi_const_SMI_ACCESS_READ_ONLY(unsigned long long *o)
{
  int n = (SMI_ACCESS_READ_ONLY) <= 0;
  *o = (unsigned long long)((SMI_ACCESS_READ_ONLY) | 0);  /* check that SMI_ACCESS_READ_ONLY is an integer */
  return n;
}

static int _cffi_const_SMI_ACCESS_READ_WRITE(unsigned long long *o)
{
  int n = (SMI_ACCESS_READ_WRITE) <= 0;
  *o = (unsigned long long)((SMI_ACCESS_READ_WRITE) | 0);  /* check that SMI_ACCESS_READ_WRITE is an integer */
  return n;
}

static int _cffi_const_SMI_BASETYPE_INTEGER32(unsigned long long *o)
{
  int n = (SMI_BASETYPE_INTEGER32) <= 0;
  *o = (unsigned long long)((SMI_BASETYPE_INTEGER32) | 0);  /* check that SMI_BASETYPE_INTEGER32 is an integer */
  return n;
}

static int _cffi_const_SMI_BASETYPE_OCTETSTRING(unsigned long long *o)
{
  int n = (SMI_BASETYPE_OCTETSTRING) <= 0;
  *o = (unsigned long long)((SMI_BASETYPE_OCTETSTRING) | 0);  /* check that SMI_BASETYPE_OCTETSTRING is an integer */
  return n;
}

static int _cffi_const_SMI_BASETYPE_OBJECTIDENTIFIER(unsigned long long *o)
{
  int n = (SMI_BASETYPE_OBJECTIDENTIFIER) <= 0;
  *o = (unsigned long long)((SMI_BASETYPE_OBJECTIDENTIFIER) | 0);  /* check that SMI_BASETYPE_OBJECTIDENTIFIER is an integer */
  return n;
}

static int _cffi_const_SMI_BASETYPE_UNSIGNED32(unsigned long long *o)
{
  int n = (SMI_BASETYPE_UNSIGNED32) <= 0;
  *o = (unsigned long long)((SMI_BASETYPE_UNSIGNED32) | 0);  /* check that SMI_BASETYPE_UNSIGNED32 is an integer */
  return n;
}

static int _cffi_const_SMI_BASETYPE_INTEGER64(unsigned long long *o)
{
  int n = (SMI_BASETYPE_INTEGER64) <= 0;
  *o = (unsigned long long)((SMI_BASETYPE_INTEGER64) | 0);  /* check that SMI_BASETYPE_INTEGER64 is an integer */
  return n;
}

static int _cffi_const_SMI_BASETYPE_UNSIGNED64(unsigned long long *o)
{
  int n = (SMI_BASETYPE_UNSIGNED64) <= 0;
  *o = (unsigned long long)((SMI_BASETYPE_UNSIGNED64) | 0);  /* check that SMI_BASETYPE_UNSIGNED64 is an integer */
  return n;
}

static int _cffi_const_SMI_BASETYPE_ENUM(unsigned long long *o)
{
  int n = (SMI_BASETYPE_ENUM) <= 0;
  *o = (unsigned long long)((SMI_BASETYPE_ENUM) | 0);  /* check that SMI_BASETYPE_ENUM is an integer */
  return n;
}

static int _cffi_const_SMI_BASETYPE_BITS(unsigned long long *o)
{
  int n = (SMI_BASETYPE_BITS) <= 0;
  *o = (unsigned long long)((SMI_BASETYPE_BITS) | 0);  /* check that SMI_BASETYPE_BITS is an integer */
  return n;
}

static int _cffi_const_SMI_INDEX_INDEX(unsigned long long *o)
{
  int n = (SMI_INDEX_INDEX) <= 0;
  *o = (unsigned long long)((SMI_INDEX_INDEX) | 0);  /* check that SMI_INDEX_INDEX is an integer */
  return n;
}

static int _cffi_const_SMI_INDEX_AUGMENT(unsigned long long *o)
{
  int n = (SMI_INDEX_AUGMENT) <= 0;
  *o = (unsigned long long)((SMI_INDEX_AUGMENT) | 0);  /* check that SMI_INDEX_AUGMENT is an integer */
  return n;
}

static void _cffi_d_free(void * x0)
{
  free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_free(PyObject *self, PyObject *arg0)
{
  void * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(87), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (void *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(87), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_free _cffi_d_free
#endif

static void _cffi_d_smiExit(void)
{
  smiExit();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiExit(PyObject *self, PyObject *noarg)
{

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { smiExit(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_smiExit _cffi_d_smiExit
#endif

static SmiNode * _cffi_d_smiGetElementNode(SmiElement * x0)
{
  return smiGetElementNode(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetElementNode(PyObject *self, PyObject *arg0)
{
  SmiElement * x0;
  Py_ssize_t datasize;
  SmiNode * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (SmiElement *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(1), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetElementNode(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(4));
}
#else
#  define _cffi_f_smiGetElementNode _cffi_d_smiGetElementNode
#endif

static SmiNode * _cffi_d_smiGetFirstChildNode(SmiNode * x0)
{
  return smiGetFirstChildNode(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetFirstChildNode(PyObject *self, PyObject *arg0)
{
  SmiNode * x0;
  Py_ssize_t datasize;
  SmiNode * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (SmiNode *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(4), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetFirstChildNode(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(4));
}
#else
#  define _cffi_f_smiGetFirstChildNode _cffi_d_smiGetFirstChildNode
#endif

static SmiElement * _cffi_d_smiGetFirstElement(SmiNode * x0)
{
  return smiGetFirstElement(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetFirstElement(PyObject *self, PyObject *arg0)
{
  SmiNode * x0;
  Py_ssize_t datasize;
  SmiElement * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (SmiNode *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(4), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetFirstElement(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(1));
}
#else
#  define _cffi_f_smiGetFirstElement _cffi_d_smiGetFirstElement
#endif

static SmiModule * _cffi_d_smiGetFirstModule(void)
{
  return smiGetFirstModule();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetFirstModule(PyObject *self, PyObject *noarg)
{
  SmiModule * result;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetFirstModule(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(7));
}
#else
#  define _cffi_f_smiGetFirstModule _cffi_d_smiGetFirstModule
#endif

static SmiNamedNumber * _cffi_d_smiGetFirstNamedNumber(SmiType * x0)
{
  return smiGetFirstNamedNumber(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetFirstNamedNumber(PyObject *self, PyObject *arg0)
{
  SmiType * x0;
  Py_ssize_t datasize;
  SmiNamedNumber * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(13), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (SmiType *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(13), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetFirstNamedNumber(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(21));
}
#else
#  define _cffi_f_smiGetFirstNamedNumber _cffi_d_smiGetFirstNamedNumber
#endif

static SmiNode * _cffi_d_smiGetFirstNode(SmiModule * x0, unsigned int x1)
{
  return smiGetFirstNode(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetFirstNode(PyObject *self, PyObject *args)
{
  SmiModule * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  SmiNode * result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "smiGetFirstNode", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (SmiModule *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(7), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetFirstNode(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(4));
}
#else
#  define _cffi_f_smiGetFirstNode _cffi_d_smiGetFirstNode
#endif

static SmiRange * _cffi_d_smiGetFirstRange(SmiType * x0)
{
  return smiGetFirstRange(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetFirstRange(PyObject *self, PyObject *arg0)
{
  SmiType * x0;
  Py_ssize_t datasize;
  SmiRange * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(13), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (SmiType *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(13), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetFirstRange(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(49));
}
#else
#  define _cffi_f_smiGetFirstRange _cffi_d_smiGetFirstRange
#endif

static SmiModule * _cffi_d_smiGetModule(char const * x0)
{
  return smiGetModule(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetModule(PyObject *self, PyObject *arg0)
{
  char const * x0;
  Py_ssize_t datasize;
  SmiModule * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (char const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(16), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetModule(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(7));
}
#else
#  define _cffi_f_smiGetModule _cffi_d_smiGetModule
#endif

static SmiNode * _cffi_d_smiGetNextChildNode(SmiNode * x0)
{
  return smiGetNextChildNode(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetNextChildNode(PyObject *self, PyObject *arg0)
{
  SmiNode * x0;
  Py_ssize_t datasize;
  SmiNode * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (SmiNode *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(4), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetNextChildNode(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(4));
}
#else
#  define _cffi_f_smiGetNextChildNode _cffi_d_smiGetNextChildNode
#endif

static SmiElement * _cffi_d_smiGetNextElement(SmiElement * x0)
{
  return smiGetNextElement(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetNextElement(PyObject *self, PyObject *arg0)
{
  SmiElement * x0;
  Py_ssize_t datasize;
  SmiElement * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (SmiElement *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(1), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetNextElement(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(1));
}
#else
#  define _cffi_f_smiGetNextElement _cffi_d_smiGetNextElement
#endif

static SmiModule * _cffi_d_smiGetNextModule(SmiModule * x0)
{
  return smiGetNextModule(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetNextModule(PyObject *self, PyObject *arg0)
{
  SmiModule * x0;
  Py_ssize_t datasize;
  SmiModule * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (SmiModule *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(7), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetNextModule(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(7));
}
#else
#  define _cffi_f_smiGetNextModule _cffi_d_smiGetNextModule
#endif

static SmiNamedNumber * _cffi_d_smiGetNextNamedNumber(SmiNamedNumber * x0)
{
  return smiGetNextNamedNumber(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetNextNamedNumber(PyObject *self, PyObject *arg0)
{
  SmiNamedNumber * x0;
  Py_ssize_t datasize;
  SmiNamedNumber * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(21), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (SmiNamedNumber *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(21), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetNextNamedNumber(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(21));
}
#else
#  define _cffi_f_smiGetNextNamedNumber _cffi_d_smiGetNextNamedNumber
#endif

static SmiNode * _cffi_d_smiGetNextNode(SmiNode * x0, unsigned int x1)
{
  return smiGetNextNode(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetNextNode(PyObject *self, PyObject *args)
{
  SmiNode * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  SmiNode * result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "smiGetNextNode", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (SmiNode *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(4), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetNextNode(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(4));
}
#else
#  define _cffi_f_smiGetNextNode _cffi_d_smiGetNextNode
#endif

static SmiRange * _cffi_d_smiGetNextRange(SmiRange * x0)
{
  return smiGetNextRange(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetNextRange(PyObject *self, PyObject *arg0)
{
  SmiRange * x0;
  Py_ssize_t datasize;
  SmiRange * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (SmiRange *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(49), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetNextRange(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(49));
}
#else
#  define _cffi_f_smiGetNextRange _cffi_d_smiGetNextRange
#endif

static SmiNode * _cffi_d_smiGetNode(SmiModule * x0, char const * x1)
{
  return smiGetNode(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetNode(PyObject *self, PyObject *args)
{
  SmiModule * x0;
  char const * x1;
  Py_ssize_t datasize;
  SmiNode * result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "smiGetNode", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (SmiModule *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(7), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(16), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetNode(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(4));
}
#else
#  define _cffi_f_smiGetNode _cffi_d_smiGetNode
#endif

static SmiNode * _cffi_d_smiGetNodeByOID(unsigned int x0, unsigned int * x1)
{
  return smiGetNodeByOID(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetNodeByOID(PyObject *self, PyObject *args)
{
  unsigned int x0;
  unsigned int * x1;
  Py_ssize_t datasize;
  SmiNode * result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "smiGetNodeByOID", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned int);
  if (x0 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(46), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (unsigned int *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(46), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetNodeByOID(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(4));
}
#else
#  define _cffi_f_smiGetNodeByOID _cffi_d_smiGetNodeByOID
#endif

static SmiModule * _cffi_d_smiGetNodeModule(SmiNode * x0)
{
  return smiGetNodeModule(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetNodeModule(PyObject *self, PyObject *arg0)
{
  SmiNode * x0;
  Py_ssize_t datasize;
  SmiModule * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (SmiNode *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(4), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetNodeModule(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(7));
}
#else
#  define _cffi_f_smiGetNodeModule _cffi_d_smiGetNodeModule
#endif

static SmiType * _cffi_d_smiGetNodeType(SmiNode * x0)
{
  return smiGetNodeType(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetNodeType(PyObject *self, PyObject *arg0)
{
  SmiNode * x0;
  Py_ssize_t datasize;
  SmiType * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (SmiNode *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(4), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetNodeType(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(13));
}
#else
#  define _cffi_f_smiGetNodeType _cffi_d_smiGetNodeType
#endif

static SmiNode * _cffi_d_smiGetParentNode(SmiNode * x0)
{
  return smiGetParentNode(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetParentNode(PyObject *self, PyObject *arg0)
{
  SmiNode * x0;
  Py_ssize_t datasize;
  SmiNode * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (SmiNode *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(4), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetParentNode(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(4));
}
#else
#  define _cffi_f_smiGetParentNode _cffi_d_smiGetParentNode
#endif

static SmiType * _cffi_d_smiGetParentType(SmiType * x0)
{
  return smiGetParentType(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetParentType(PyObject *self, PyObject *arg0)
{
  SmiType * x0;
  Py_ssize_t datasize;
  SmiType * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(13), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (SmiType *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(13), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetParentType(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(13));
}
#else
#  define _cffi_f_smiGetParentType _cffi_d_smiGetParentType
#endif

static char * _cffi_d_smiGetPath(void)
{
  return smiGetPath();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetPath(PyObject *self, PyObject *noarg)
{
  char * result;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetPath(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(56));
}
#else
#  define _cffi_f_smiGetPath _cffi_d_smiGetPath
#endif

static SmiNode * _cffi_d_smiGetRelatedNode(SmiNode * x0)
{
  return smiGetRelatedNode(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetRelatedNode(PyObject *self, PyObject *arg0)
{
  SmiNode * x0;
  Py_ssize_t datasize;
  SmiNode * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (SmiNode *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(4), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetRelatedNode(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(4));
}
#else
#  define _cffi_f_smiGetRelatedNode _cffi_d_smiGetRelatedNode
#endif

static SmiType * _cffi_d_smiGetType(SmiModule * x0, char * x1)
{
  return smiGetType(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetType(PyObject *self, PyObject *args)
{
  SmiModule * x0;
  char * x1;
  Py_ssize_t datasize;
  SmiType * result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "smiGetType", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (SmiModule *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(7), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(56), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetType(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(13));
}
#else
#  define _cffi_f_smiGetType _cffi_d_smiGetType
#endif

static SmiModule * _cffi_d_smiGetTypeModule(SmiType * x0)
{
  return smiGetTypeModule(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiGetTypeModule(PyObject *self, PyObject *arg0)
{
  SmiType * x0;
  Py_ssize_t datasize;
  SmiModule * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(13), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (SmiType *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(13), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiGetTypeModule(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(7));
}
#else
#  define _cffi_f_smiGetTypeModule _cffi_d_smiGetTypeModule
#endif

static int _cffi_d_smiInit(char const * x0)
{
  return smiInit(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiInit(PyObject *self, PyObject *arg0)
{
  char const * x0;
  Py_ssize_t datasize;
  int result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (char const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(16), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiInit(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_smiInit _cffi_d_smiInit
#endif

static char * _cffi_d_smiLoadModule(char const * x0)
{
  return smiLoadModule(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiLoadModule(PyObject *self, PyObject *arg0)
{
  char const * x0;
  Py_ssize_t datasize;
  char * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (char const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(16), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiLoadModule(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(56));
}
#else
#  define _cffi_f_smiLoadModule _cffi_d_smiLoadModule
#endif

static char * _cffi_d_smiRenderNode(SmiNode * x0, int x1)
{
  return smiRenderNode(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiRenderNode(PyObject *self, PyObject *args)
{
  SmiNode * x0;
  int x1;
  Py_ssize_t datasize;
  char * result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "smiRenderNode", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (SmiNode *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(4), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiRenderNode(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(56));
}
#else
#  define _cffi_f_smiRenderNode _cffi_d_smiRenderNode
#endif

static void _cffi_d_smiSetErrorHandler(void(* x0)(char *, int, int, char *, char *))
{
  smiSetErrorHandler(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiSetErrorHandler(PyObject *self, PyObject *arg0)
{
  void(* x0)(char *, int, int, char *, char *);

  x0 = (void(*)(char *, int, int, char *, char *))_cffi_to_c_pointer(arg0, _cffi_type(90));
  if (x0 == (void(*)(char *, int, int, char *, char *))NULL && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { smiSetErrorHandler(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_smiSetErrorHandler _cffi_d_smiSetErrorHandler
#endif

static void _cffi_d_smiSetErrorLevel(int x0)
{
  smiSetErrorLevel(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiSetErrorLevel(PyObject *self, PyObject *arg0)
{
  int x0;

  x0 = _cffi_to_c_int(arg0, int);
  if (x0 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { smiSetErrorLevel(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_smiSetErrorLevel _cffi_d_smiSetErrorLevel
#endif

static void _cffi_d_smiSetFlags(int x0)
{
  smiSetFlags(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiSetFlags(PyObject *self, PyObject *arg0)
{
  int x0;

  x0 = _cffi_to_c_int(arg0, int);
  if (x0 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { smiSetFlags(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_smiSetFlags _cffi_d_smiSetFlags
#endif

static int _cffi_d_smiSetPath(char const * x0)
{
  return smiSetPath(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_smiSetPath(PyObject *self, PyObject *arg0)
{
  char const * x0;
  Py_ssize_t datasize;
  int result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (char const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(16), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = smiSetPath(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_smiSetPath _cffi_d_smiSetPath
#endif

static int _cffi_const_SMI_FLAG_ERRORS(unsigned long long *o)
{
  int n = (SMI_FLAG_ERRORS) <= 0;
  *o = (unsigned long long)((SMI_FLAG_ERRORS) | 0);  /* check that SMI_FLAG_ERRORS is an integer */
  return n;
}

static int _cffi_const_SMI_FLAG_RECURSIVE(unsigned long long *o)
{
  int n = (SMI_FLAG_RECURSIVE) <= 0;
  *o = (unsigned long long)((SMI_FLAG_RECURSIVE) | 0);  /* check that SMI_FLAG_RECURSIVE is an integer */
  return n;
}

static int _cffi_const_SMI_NODEKIND_COLUMN(unsigned long long *o)
{
  int n = (SMI_NODEKIND_COLUMN) <= 0;
  *o = (unsigned long long)((SMI_NODEKIND_COLUMN) | 0);  /* check that SMI_NODEKIND_COLUMN is an integer */
  return n;
}

static int _cffi_const_SMI_NODEKIND_NODE(unsigned long long *o)
{
  int n = (SMI_NODEKIND_NODE) <= 0;
  *o = (unsigned long long)((SMI_NODEKIND_NODE) | 0);  /* check that SMI_NODEKIND_NODE is an integer */
  return n;
}

static int _cffi_const_SMI_NODEKIND_NOTIFICATION(unsigned long long *o)
{
  int n = (SMI_NODEKIND_NOTIFICATION) <= 0;
  *o = (unsigned long long)((SMI_NODEKIND_NOTIFICATION) | 0);  /* check that SMI_NODEKIND_NOTIFICATION is an integer */
  return n;
}

static int _cffi_const_SMI_NODEKIND_ROW(unsigned long long *o)
{
  int n = (SMI_NODEKIND_ROW) <= 0;
  *o = (unsigned long long)((SMI_NODEKIND_ROW) | 0);  /* check that SMI_NODEKIND_ROW is an integer */
  return n;
}

static int _cffi_const_SMI_NODEKIND_SCALAR(unsigned long long *o)
{
  int n = (SMI_NODEKIND_SCALAR) <= 0;
  *o = (unsigned long long)((SMI_NODEKIND_SCALAR) | 0);  /* check that SMI_NODEKIND_SCALAR is an integer */
  return n;
}

static int _cffi_const_SMI_NODEKIND_TABLE(unsigned long long *o)
{
  int n = (SMI_NODEKIND_TABLE) <= 0;
  *o = (unsigned long long)((SMI_NODEKIND_TABLE) | 0);  /* check that SMI_NODEKIND_TABLE is an integer */
  return n;
}

static int _cffi_const_SMI_RENDER_ALL(unsigned long long *o)
{
  int n = (SMI_RENDER_ALL) <= 0;
  *o = (unsigned long long)((SMI_RENDER_ALL) | 0);  /* check that SMI_RENDER_ALL is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld__SmiElement(SmiElement *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
}
struct _cffi_align__SmiElement { char x; SmiElement y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__SmiModule(SmiModule *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char * *tmp = &p->name; (void)tmp; }
  (void)((p->conformance) | 0);  /* check that 'SmiModule.conformance' is an integer */
}
struct _cffi_align__SmiModule { char x; SmiModule y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__SmiNamedNumber(SmiNamedNumber *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char * *tmp = &p->name; (void)tmp; }
  { SmiValue *tmp = &p->value; (void)tmp; }
}
struct _cffi_align__SmiNamedNumber { char x; SmiNamedNumber y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__SmiNode(SmiNode *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char * *tmp = &p->name; (void)tmp; }
  (void)((p->oidlen) | 0);  /* check that 'SmiNode.oidlen' is an integer */
  { unsigned int * *tmp = &p->oid; (void)tmp; }
  { char * *tmp = &p->format; (void)tmp; }
  { SmiIndexkind *tmp = &p->indexkind; (void)tmp; }
  (void)((p->implied) | 0);  /* check that 'SmiNode.implied' is an integer */
  (void)((p->nodekind) | 0);  /* check that 'SmiNode.nodekind' is an integer */
  { SmiAccess *tmp = &p->access; (void)tmp; }
}
struct _cffi_align__SmiNode { char x; SmiNode y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__SmiRange(SmiRange *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { SmiValue *tmp = &p->minValue; (void)tmp; }
  { SmiValue *tmp = &p->maxValue; (void)tmp; }
}
struct _cffi_align__SmiRange { char x; SmiRange y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__SmiType(SmiType *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char * *tmp = &p->name; (void)tmp; }
  { SmiBasetype *tmp = &p->basetype; (void)tmp; }
  { char * *tmp = &p->format; (void)tmp; }
}
struct _cffi_align__SmiType { char x; SmiType y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__SmiValue(SmiValue *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { SmiBasetype *tmp = &p->basetype; (void)tmp; }
  /* cannot generate 'union $1' in field 'value': unknown type name */
}
struct _cffi_align__SmiValue { char x; SmiValue y; };

static const struct _cffi_global_s _cffi_globals[] = {
  { "SMI_ACCESS_NOT_ACCESSIBLE", (void *)_cffi_const_SMI_ACCESS_NOT_ACCESSIBLE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SMI_ACCESS_NOT_IMPLEMENTED", (void *)_cffi_const_SMI_ACCESS_NOT_IMPLEMENTED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SMI_ACCESS_READ_ONLY", (void *)_cffi_const_SMI_ACCESS_READ_ONLY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SMI_ACCESS_READ_WRITE", (void *)_cffi_const_SMI_ACCESS_READ_WRITE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SMI_BASETYPE_BITS", (void *)_cffi_const_SMI_BASETYPE_BITS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SMI_BASETYPE_ENUM", (void *)_cffi_const_SMI_BASETYPE_ENUM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SMI_BASETYPE_INTEGER32", (void *)_cffi_const_SMI_BASETYPE_INTEGER32, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SMI_BASETYPE_INTEGER64", (void *)_cffi_const_SMI_BASETYPE_INTEGER64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SMI_BASETYPE_OBJECTIDENTIFIER", (void *)_cffi_const_SMI_BASETYPE_OBJECTIDENTIFIER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SMI_BASETYPE_OCTETSTRING", (void *)_cffi_const_SMI_BASETYPE_OCTETSTRING, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SMI_BASETYPE_UNSIGNED32", (void *)_cffi_const_SMI_BASETYPE_UNSIGNED32, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SMI_BASETYPE_UNSIGNED64", (void *)_cffi_const_SMI_BASETYPE_UNSIGNED64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SMI_FLAG_ERRORS", (void *)_cffi_const_SMI_FLAG_ERRORS, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "SMI_FLAG_RECURSIVE", (void *)_cffi_const_SMI_FLAG_RECURSIVE, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "SMI_INDEX_AUGMENT", (void *)_cffi_const_SMI_INDEX_AUGMENT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SMI_INDEX_INDEX", (void *)_cffi_const_SMI_INDEX_INDEX, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "SMI_NODEKIND_COLUMN", (void *)_cffi_const_SMI_NODEKIND_COLUMN, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "SMI_NODEKIND_NODE", (void *)_cffi_const_SMI_NODEKIND_NODE, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "SMI_NODEKIND_NOTIFICATION", (void *)_cffi_const_SMI_NODEKIND_NOTIFICATION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "SMI_NODEKIND_ROW", (void *)_cffi_const_SMI_NODEKIND_ROW, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "SMI_NODEKIND_SCALAR", (void *)_cffi_const_SMI_NODEKIND_SCALAR, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "SMI_NODEKIND_TABLE", (void *)_cffi_const_SMI_NODEKIND_TABLE, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "SMI_RENDER_ALL", (void *)_cffi_const_SMI_RENDER_ALL, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "free", (void *)_cffi_f_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 86), (void *)_cffi_d_free },
  { "smiExit", (void *)_cffi_f_smiExit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 92), (void *)_cffi_d_smiExit },
  { "smiGetElementNode", (void *)_cffi_f_smiGetElementNode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 26), (void *)_cffi_d_smiGetElementNode },
  { "smiGetFirstChildNode", (void *)_cffi_f_smiGetFirstChildNode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 37), (void *)_cffi_d_smiGetFirstChildNode },
  { "smiGetFirstElement", (void *)_cffi_f_smiGetFirstElement, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 3), (void *)_cffi_d_smiGetFirstElement },
  { "smiGetFirstModule", (void *)_cffi_f_smiGetFirstModule, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 18), (void *)_cffi_d_smiGetFirstModule },
  { "smiGetFirstNamedNumber", (void *)_cffi_f_smiGetFirstNamedNumber, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 23), (void *)_cffi_d_smiGetFirstNamedNumber },
  { "smiGetFirstNode", (void *)_cffi_f_smiGetFirstNode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 33), (void *)_cffi_d_smiGetFirstNode },
  { "smiGetFirstRange", (void *)_cffi_f_smiGetFirstRange, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 51), (void *)_cffi_d_smiGetFirstRange },
  { "smiGetModule", (void *)_cffi_f_smiGetModule, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 15), (void *)_cffi_d_smiGetModule },
  { "smiGetNextChildNode", (void *)_cffi_f_smiGetNextChildNode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 37), (void *)_cffi_d_smiGetNextChildNode },
  { "smiGetNextElement", (void *)_cffi_f_smiGetNextElement, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 0), (void *)_cffi_d_smiGetNextElement },
  { "smiGetNextModule", (void *)_cffi_f_smiGetNextModule, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 6), (void *)_cffi_d_smiGetNextModule },
  { "smiGetNextNamedNumber", (void *)_cffi_f_smiGetNextNamedNumber, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 20), (void *)_cffi_d_smiGetNextNamedNumber },
  { "smiGetNextNode", (void *)_cffi_f_smiGetNextNode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 40), (void *)_cffi_d_smiGetNextNode },
  { "smiGetNextRange", (void *)_cffi_f_smiGetNextRange, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 48), (void *)_cffi_d_smiGetNextRange },
  { "smiGetNode", (void *)_cffi_f_smiGetNode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 29), (void *)_cffi_d_smiGetNode },
  { "smiGetNodeByOID", (void *)_cffi_f_smiGetNodeByOID, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 44), (void *)_cffi_d_smiGetNodeByOID },
  { "smiGetNodeModule", (void *)_cffi_f_smiGetNodeModule, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 9), (void *)_cffi_d_smiGetNodeModule },
  { "smiGetNodeType", (void *)_cffi_f_smiGetNodeType, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 58), (void *)_cffi_d_smiGetNodeType },
  { "smiGetParentNode", (void *)_cffi_f_smiGetParentNode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 37), (void *)_cffi_d_smiGetParentNode },
  { "smiGetParentType", (void *)_cffi_f_smiGetParentType, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 61), (void *)_cffi_d_smiGetParentType },
  { "smiGetPath", (void *)_cffi_f_smiGetPath, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 71), (void *)_cffi_d_smiGetPath },
  { "smiGetRelatedNode", (void *)_cffi_f_smiGetRelatedNode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 37), (void *)_cffi_d_smiGetRelatedNode },
  { "smiGetType", (void *)_cffi_f_smiGetType, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 54), (void *)_cffi_d_smiGetType },
  { "smiGetTypeModule", (void *)_cffi_f_smiGetTypeModule, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 12), (void *)_cffi_d_smiGetTypeModule },
  { "smiInit", (void *)_cffi_f_smiInit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 73), (void *)_cffi_d_smiInit },
  { "smiLoadModule", (void *)_cffi_f_smiLoadModule, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 68), (void *)_cffi_d_smiLoadModule },
  { "smiRenderNode", (void *)_cffi_f_smiRenderNode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 64), (void *)_cffi_d_smiRenderNode },
  { "smiSetErrorHandler", (void *)_cffi_f_smiSetErrorHandler, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 89), (void *)_cffi_d_smiSetErrorHandler },
  { "smiSetErrorLevel", (void *)_cffi_f_smiSetErrorLevel, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 83), (void *)_cffi_d_smiSetErrorLevel },
  { "smiSetFlags", (void *)_cffi_f_smiSetFlags, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 83), (void *)_cffi_d_smiSetFlags },
  { "smiSetPath", (void *)_cffi_f_smiSetPath, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 73), (void *)_cffi_d_smiSetPath },
};

static const struct _cffi_field_s _cffi_fields[] = {
  { "name", offsetof(SmiModule, name),
            sizeof(((SmiModule *)0)->name),
            _CFFI_OP(_CFFI_OP_NOOP, 56) },
  { "conformance", offsetof(SmiModule, conformance),
                   sizeof(((SmiModule *)0)->conformance),
                   _CFFI_OP(_CFFI_OP_NOOP, 66) },
  { "name", offsetof(SmiNamedNumber, name),
            sizeof(((SmiNamedNumber *)0)->name),
            _CFFI_OP(_CFFI_OP_NOOP, 56) },
  { "value", offsetof(SmiNamedNumber, value),
             sizeof(((SmiNamedNumber *)0)->value),
             _CFFI_OP(_CFFI_OP_NOOP, 103) },
  { "name", offsetof(SmiNode, name),
            sizeof(((SmiNode *)0)->name),
            _CFFI_OP(_CFFI_OP_NOOP, 56) },
  { "oidlen", offsetof(SmiNode, oidlen),
              sizeof(((SmiNode *)0)->oidlen),
              _CFFI_OP(_CFFI_OP_NOOP, 35) },
  { "oid", offsetof(SmiNode, oid),
           sizeof(((SmiNode *)0)->oid),
           _CFFI_OP(_CFFI_OP_NOOP, 46) },
  { "format", offsetof(SmiNode, format),
              sizeof(((SmiNode *)0)->format),
              _CFFI_OP(_CFFI_OP_NOOP, 56) },
  { "indexkind", offsetof(SmiNode, indexkind),
                 sizeof(((SmiNode *)0)->indexkind),
                 _CFFI_OP(_CFFI_OP_NOOP, 97) },
  { "implied", offsetof(SmiNode, implied),
               sizeof(((SmiNode *)0)->implied),
               _CFFI_OP(_CFFI_OP_NOOP, 66) },
  { "nodekind", offsetof(SmiNode, nodekind),
                sizeof(((SmiNode *)0)->nodekind),
                _CFFI_OP(_CFFI_OP_NOOP, 35) },
  { "access", offsetof(SmiNode, access),
              sizeof(((SmiNode *)0)->access),
              _CFFI_OP(_CFFI_OP_NOOP, 94) },
  { "minValue", offsetof(SmiRange, minValue),
                sizeof(((SmiRange *)0)->minValue),
                _CFFI_OP(_CFFI_OP_NOOP, 103) },
  { "maxValue", offsetof(SmiRange, maxValue),
                sizeof(((SmiRange *)0)->maxValue),
                _CFFI_OP(_CFFI_OP_NOOP, 103) },
  { "name", offsetof(SmiType, name),
            sizeof(((SmiType *)0)->name),
            _CFFI_OP(_CFFI_OP_NOOP, 56) },
  { "basetype", offsetof(SmiType, basetype),
                sizeof(((SmiType *)0)->basetype),
                _CFFI_OP(_CFFI_OP_NOOP, 95) },
  { "format", offsetof(SmiType, format),
              sizeof(((SmiType *)0)->format),
              _CFFI_OP(_CFFI_OP_NOOP, 56) },
  { "basetype", offsetof(SmiValue, basetype),
                sizeof(((SmiValue *)0)->basetype),
                _CFFI_OP(_CFFI_OP_NOOP, 95) },
  { "value", offsetof(SmiValue, value),
             sizeof(((SmiValue *)0)->value),
             _CFFI_OP(_CFFI_OP_NOOP, 110) },
  { "unsigned64", (size_t)-1,
                  (size_t)-1,
                  _CFFI_OP(_CFFI_OP_NOOP, 111) },
  { "integer64", (size_t)-1,
                 (size_t)-1,
                 _CFFI_OP(_CFFI_OP_NOOP, 108) },
  { "unsigned32", (size_t)-1,
                  (size_t)-1,
                  _CFFI_OP(_CFFI_OP_NOOP, 112) },
  { "integer32", (size_t)-1,
                 (size_t)-1,
                 _CFFI_OP(_CFFI_OP_NOOP, 109) },
  { "float32", (size_t)-1,
               (size_t)-1,
               _CFFI_OP(_CFFI_OP_NOOP, 106) },
  { "float64", (size_t)-1,
               (size_t)-1,
               _CFFI_OP(_CFFI_OP_NOOP, 105) },
  { "float128", (size_t)-1,
                (size_t)-1,
                _CFFI_OP(_CFFI_OP_NOOP, 107) },
  { "oid", (size_t)-1,
           (size_t)-1,
           _CFFI_OP(_CFFI_OP_NOOP, 46) },
  { "ptr", (size_t)-1,
           (size_t)-1,
           _CFFI_OP(_CFFI_OP_NOOP, 56) },
};

static const struct _cffi_struct_union_s _cffi_struct_unions[] = {
  { "$1", 110, _CFFI_F_UNION|_CFFI_F_CHECK_FIELDS,
    (size_t)-2, -2, 19, 9 /* unnamed */ },
  { "SmiElement", 96, 0,
    sizeof(SmiElement), offsetof(struct _cffi_align__SmiElement, y), 0, 0 },
  { "SmiModule", 98, 0,
    sizeof(SmiModule), offsetof(struct _cffi_align__SmiModule, y), 0, 2 },
  { "SmiNamedNumber", 99, 0,
    sizeof(SmiNamedNumber), offsetof(struct _cffi_align__SmiNamedNumber, y), 2, 2 },
  { "SmiNode", 100, 0,
    sizeof(SmiNode), offsetof(struct _cffi_align__SmiNode, y), 4, 8 },
  { "SmiRange", 101, 0,
    sizeof(SmiRange), offsetof(struct _cffi_align__SmiRange, y), 12, 2 },
  { "SmiType", 102, 0,
    sizeof(SmiType), offsetof(struct _cffi_align__SmiType, y), 14, 3 },
  { "SmiValue", 103, 0,
    sizeof(SmiValue), offsetof(struct _cffi_align__SmiValue, y), 17, 2 },
};

static const struct _cffi_enum_s _cffi_enums[] = {
  { "SmiAccess", 94, _cffi_prim_int(sizeof(SmiAccess), ((SmiAccess)-1) <= 0),
    "SMI_ACCESS_NOT_IMPLEMENTED,SMI_ACCESS_NOT_ACCESSIBLE,SMI_ACCESS_READ_ONLY,SMI_ACCESS_READ_WRITE" },
  { "SmiBasetype", 95, _cffi_prim_int(sizeof(SmiBasetype), ((SmiBasetype)-1) <= 0),
    "SMI_BASETYPE_INTEGER32,SMI_BASETYPE_OCTETSTRING,SMI_BASETYPE_OBJECTIDENTIFIER,SMI_BASETYPE_UNSIGNED32,SMI_BASETYPE_INTEGER64,SMI_BASETYPE_UNSIGNED64,SMI_BASETYPE_ENUM,SMI_BASETYPE_BITS" },
  { "SmiIndexkind", 97, _cffi_prim_int(sizeof(SmiIndexkind), ((SmiIndexkind)-1) <= 0),
    "SMI_INDEX_INDEX,SMI_INDEX_AUGMENT" },
};

static const struct _cffi_typename_s _cffi_typenames[] = {
  { "SmiAccess", 94 },
  { "SmiBasetype", 95 },
  { "SmiElement", 96 },
  { "SmiErrorHandler", 76 },
  { "SmiFloat128", 107 },
  { "SmiFloat32", 106 },
  { "SmiFloat64", 105 },
  { "SmiIdentifier", 56 },
  { "SmiIndexkind", 97 },
  { "SmiInteger32", 109 },
  { "SmiInteger64", 108 },
  { "SmiModule", 98 },
  { "SmiNamedNumber", 99 },
  { "SmiNode", 100 },
  { "SmiNodekind", 35 },
  { "SmiRange", 101 },
  { "SmiSubid", 35 },
  { "SmiType", 102 },
  { "SmiUnsigned32", 112 },
  { "SmiUnsigned64", 111 },
  { "SmiValue", 103 },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  _cffi_fields,
  _cffi_struct_unions,
  _cffi_enums,
  _cffi_typenames,
  56,  /* num_globals */
  8,  /* num_struct_unions */
  3,  /* num_enums */
  21,  /* num_typenames */
  NULL,  /* no includes */
  114,  /* num_types */
  0,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit__smi(const void *p[])
{
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit__smi(void) { return NULL; }
#  else
     init_smi(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit__smi(void)
{
  return _cffi_init("snimpy._smi", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
init_smi(void)
{
  _cffi_init("snimpy._smi", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
